pm4py.objects.random\_variables.normal package
==============================================

Submodules
----------

pm4py.objects.random\_variables.normal.random\_variable module
--------------------------------------------------------------

.. automodule:: pm4py.objects.random_variables.normal.random_variable
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.objects.random_variables.normal
   :members:
   :undoc-members:
   :show-inheritance:
